==> haskell-apply-refact-0.14.0.0-57.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.14.0.0
visibility:           public
id:                   apply-refact-0.14.0.0-2C5hnNvmFAq91blNTqQuBV
key:                  apply-refact-0.14.0.0-2C5hnNvmFAq91blNTqQuBV
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  618b4fdbf058049c84fc6e375e189fdd
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.14.0.0-2C5hnNvmFAq91blNTqQuBV
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy
    filemanip-0.3.6.3-6V4CNJFHbtkIqz2ftt7SXD ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    process-1.6.19.0 refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt transformers-0.6.1.0
    uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN
    unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-apply-refact-0.14.0.0-58-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.14.0.0
visibility:           public
id:                   apply-refact-0.14.0.0-5w73fjshmyFHf0ylLWm7lu
key:                  apply-refact-0.14.0.0-5w73fjshmyFHf0ylLWm7lu
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  02073d2b743d244f5d68c7df2f1f4b70
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.14.0.0-5w73fjshmyFHf0ylLWm7lu
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb
    filemanip-0.3.6.3-ZKF7Yf0QS1DhtpRpoSM7p ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9 process-1.6.19.0
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp transformers-0.6.1.0
    uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
